From e2f9ae397083710cd94b97296a925ebae7e28961 Mon Sep 17 00:00:00 2001
From: Michael Vogel <icarus@dabo.de>
Date: Thu, 24 Jul 2014 22:53:09 +0200
Subject: [PATCH] Removing of some warnings

---
 include/text.php                              | 19 ++++++++++---------
 index.php                                     |  6 +++---
 .../inc/exceptions/QueryException.class.php   | 16 +++++++++-------
 3 files changed, 22 insertions(+), 19 deletions(-)

diff --git a/include/text.php b/include/text.php
index 3c08fe378..26de709e3 100644
--- a/include/text.php
+++ b/include/text.php
@@ -655,7 +655,7 @@ function attribute_contains($attr,$s) {
 if(! function_exists('logger')) {
 /* setup int->string log level map */
 $LOGGER_LEVELS = array();
-	
+
 /**
  * log levels:
  * LOGGER_NORMAL (default)
@@ -663,7 +663,7 @@ $LOGGER_LEVELS = array();
  * LOGGER_DEBUG
  * LOGGER_DATA
  * LOGGER_ALL
- * 
+ *
  * @global App $a
  * @global dba $db
  * @param string $msg
@@ -674,15 +674,16 @@ function logger($msg,$level = 0) {
 	global $a;
 	global $db;
 	global $LOGGER_LEVELS;
-	
+
 	if(($a->module == 'install') || (! ($db && $db->connected))) return;
 
-    if (count($LOGGER_LEVEL)==0){
-        foreach (get_defined_constants() as $k=>$v){
-            if (substr($k,0,7)=="LOGGER_") $LOGGER_LEVELS[$v] = substr($k,7,7);
-        }        
-    }
-    
+	if (count($LOGGER_LEVELS)==0){
+		foreach (get_defined_constants() as $k=>$v){
+			if (substr($k,0,7)=="LOGGER_")
+				$LOGGER_LEVELS[$v] = substr($k,7,7);
+		}
+	}
+
 	$debugging = get_config('system','debugging');
 	$loglevel  = intval(get_config('system','loglevel'));
 	$logfile   = get_config('system','logfile');
diff --git a/index.php b/index.php
index 335547d74..1b6007153 100644
--- a/index.php
+++ b/index.php
@@ -432,7 +432,7 @@ else
 $a->page['htmlhead'] = str_replace('{{$stylesheet}}',$stylesheet,$a->page['htmlhead']);
 //$a->page['htmlhead'] = replace_macros($a->page['htmlhead'], array('$stylesheet' => $stylesheet));
 
-if (($_GET["mode"] == "raw") OR ($_GET["mode"] == "minimal")) {
+if (isset($_GET["mode"]) AND (($_GET["mode"] == "raw") OR ($_GET["mode"] == "minimal"))) {
 	$doc = new DOMDocument();
 
 	$target = new DOMDocument();
@@ -455,7 +455,7 @@ if (($_GET["mode"] == "raw") OR ($_GET["mode"] == "minimal")) {
 	}
 }
 
-if ($_GET["mode"] == "raw") {
+if (isset($_GET["mode"]) AND ($_GET["mode"] == "raw")) {
 
 	header("Content-type: text/html; charset=utf-8");
 
@@ -528,7 +528,7 @@ $profile = $a->profile;
 header("Content-type: text/html; charset=utf-8");
 
 
-if ($_GET["mode"] == "minimal") {
+if (isset($_GET["mode"]) AND ($_GET["mode"] == "minimal")) {
 	//$page['content'] = substr($target->saveHTML(), 6, -8)."\n\n".
 	//			'<div id="conversation-end"></div>'."\n\n";
 
diff --git a/library/dddbl2/inc/exceptions/QueryException.class.php b/library/dddbl2/inc/exceptions/QueryException.class.php
index 52c625047..e282a18c9 100644
--- a/library/dddbl2/inc/exceptions/QueryException.class.php
+++ b/library/dddbl2/inc/exceptions/QueryException.class.php
@@ -19,7 +19,7 @@ class QueryException extends \Exception {
     * and print them as exception
     *
     **/
-    public function __construct(\PDOStatement $objPDO, $arrQueryDefinition) {
+    public function __construct(\PDOStatement $objPDO, array $arrQueryDefinition) {
         
         $strMessage = self::createErrorMessage($objPDO, $arrQueryDefinition);
         
@@ -38,7 +38,7 @@ class QueryException extends \Exception {
     * and query definition
     *
     **/
-    private function createErrorMessage($objPDO, $arrQueryDefinition) {
+    private function createErrorMessage(\PDOStatement $objPDO, array $arrQueryDefinition) {
       
       $strMessage  = self::flattenQueryErrorInfo($objPDO);
       $strMessage .= self::flattenQueryDefiniton($arrQueryDefinition);
@@ -57,7 +57,7 @@ class QueryException extends \Exception {
     * from the driver specific error message
     *
     **/
-    private function flattenQueryErrorInfo($objPDO) {
+    private function flattenQueryErrorInfo(\PDOStatement $objPDO) {
     
       $arrErrorInfo = $objPDO->errorInfo();
       
@@ -76,16 +76,18 @@ class QueryException extends \Exception {
     * 
     * @return (string) a text version of the query definition
     * 
     * create an text, which contains all information 
     * of the query definition
     *
     **/
-    private function flattenQueryDefiniton($arrQueryDefinition) {
+    private function flattenQueryDefiniton(array $arrQueryDefinition) {
       
       $strMessage = "\nQuery-Definiton:\n";
       
       foreach($arrQueryDefinition AS $strKeyword => $strContent)
-        $strMessage .= "$strKeyword: $strContent\n";
+        if(is_scalar($strContent))
+          $strMessage .= "$strKeyword: $strContent\n";
       
       return $strMessage . "\n";
@@ -76,16 +76,18 @@ class QueryException extends \Exception {
     * @return (string) a text version of the query definition
     * 
-    * create an text, which contains all information 
-    * of the query definition
+    * create an text, which contains all *scalar* information 
+    * of the query definition. if there are non-scalar information
+    * added, the will be excluded from output
     *
     **/